#include "examples.h"

const int DIMENSIONS = 3;    // number of dimensions
const int ITERATIONS = 18;   // number of iterations
                             // keep ITERATIONS <= 18 for gnuplot to work properly
                             // keep ITERATIONS <= 20 for memory allocation

const double BOX_K = 20.0;    // size of initial box [-BOX_K, BOX_K]
const double MAX_TIME = 1.0; // maximum time value

const int doLog = 0;         // 0 means no log files; 1 means create log files
const int doPlot = 1;        // 0 means no log files; 1 means create log files

const int dim1 = 0; // first dimension for 3d plot, usually 0
const int dim2 = 1; // second dimension for 3d plot, usually 1
const double MIN_RES = 0.01; // small cubes are not visible in gnuplot

char *equationName = "x0' = sigma (x1 - x0), x1' = (x0 + 15) (rho - 36 - x2) - (x1 + 15), x2' = (x0 + 15) (x1 + 15) - beta (x2 + 36); x0(0) = 0, x1(0) = 0, x2(0) = 0";

void computeDerivativeValue(int dim, mpfi_t v, mpfi_t x[DIMENSIONS]) {
	double sigma = 10.0;
	double rho = 28.0;
	double beta = 8.0 / 3.0;

	mpfi_t _temp_fi, y0, y1, y2;
	mpfi_init(_temp_fi);
	mpfi_init(y0);
	mpfi_init(y1);
	mpfi_init(y2);

	mpfi_add_d(y0, x[0], 15);
	mpfi_add_d(y1, x[1], 15);
	mpfi_add_d(y2, x[2], 36);

	switch (dim) {
	case 0:
		mpfi_sub(_temp_fi, y1, y0);
		mpfi_mul_d(v, _temp_fi, sigma);
		//mpfi_add_d(v, v, 1);
		break;
	case 1:
		mpfi_d_sub(v, rho, y2);
		mpfi_mul(_temp_fi, v, y0);
		mpfi_sub(v, _temp_fi, y1);
		break;
	case 2:
		mpfi_mul(v, y0, y1);
		mpfi_mul_d(_temp_fi, y2, beta);
		mpfi_sub(v, v, _temp_fi);
		break;
	}

	mpfi_clear(_temp_fi);
	mpfi_clear(y0);
	mpfi_clear(y1);
	mpfi_clear(y2);
}

/*
char *equationName = "x0' = sigma (x1 - x0), x1' = x0 (rho - x2) - x1, x2' = x0 x1 - beta x2; x0(0) = 15, x1(0) = 15, x2(0) = 36";

void computeDerivativeValue(int dim, mpfi_t v, mpfi_t x[DIMENSIONS]) {
	double sigma = 10.0;
	double rho = 28.0;
	double beta = 8.0 / 3.0;

	mpfi_t _temp_fi;
	mpfi_init(_temp_fi);

	switch (dim) {
	case 0:
		mpfi_sub(_temp_fi, x[1], x[0]);
		mpfi_mul_d(v, _temp_fi, sigma);
		//mpfi_add_d(v, v, 1);
		break;
	case 1:
		mpfi_d_sub(v, rho, x[2]);
		mpfi_mul(_temp_fi, v, x[0]);
		mpfi_sub(v, _temp_fi, x[1]);
		break;
	case 2:
		mpfi_mul(v, x[0], x[1]);
		mpfi_mul_d(_temp_fi, x[2], beta);
		mpfi_sub(v, v, _temp_fi);
		break;
	}

	mpfi_clear(_temp_fi);
}
*/
